pub type BytesTrie<K, V> = Trie<K, V, BytesKeyConverter<K>>;Expand description
Type alias for a Trie that uses byte-based keys (anything implementing AsRef<u8>)
This provides a convenient type for working with any keys that can be converted to byte slices.
Examples of compatible types include: Vec<u8>, &[u8], etc.
Aliased Type
pub struct BytesTrie<K, V> { /* private fields */ }